<template>
  <el-dialog
    v-diadrag
    width="60%"
    title="新增"
    top="5vh"
    :visible.sync="innerVisible"
    append-to-body
    @close="$emit('update:currshowlist', false)"
    :show="currshowlist"
    class="part-dialog"
    id="part-dialog"
  >
    <ttable
      :table="table"
      @handleSelectionChange="handleSelectionChange"
      @currentChange="handleCurrentChange"
      :uploadInfo="uploadInfo"
      :prelang="prelang"
      :options="options"
      :bottomOffset="350"
      :ajaxFun="ajaxFun"
      :paramObj="paramObj"
      :selColValArr="paramTemplateSelArr"
      :selCol="paramTemplateSelCol"
      ref="commonPartTable"
    >
      <template #toolbar></template>
    </ttable>

    <div slot="footer" class="dialog-footer">
      <el-button @click="innerVisible = false">取 消</el-button>
      <el-button type="primary" @click="saveSelectRow">确 定</el-button>
    </div>
  </el-dialog>
</template>
<script>
import { fetchList, fetchListByLocNo } from '@/api/warehouse/stock'
import { IFSUpdate, queryUsingApplyDetail } from '@/api/warehouse/returnstock'
import ttable from '@/views/common/ztt-table'
import { remote } from '@/api/admin/dict'

export default {
  props: {
    currshowlist: {
      type: Boolean,
      default: false
    },
    paramObj: {
      type: Object,
      default: () => {
        return {}
      }
    },
    multiSelect: {
      type: Boolean,
      default: false
    },
    parentSelectedObj: {
      type: Object,
      default: null
    },
    parentSelectedIndex: {
      type: Number,
      default: null
    }
  },
  data() {
    return {
      ajaxFun: fetchListByLocNo,
      innerVisible: false,
      listLoading: true,
      currentRow: null,
      multipleSelection: [],
      uploadInfo: {
        // 是否展示上传EXCEL以及对应的url
        isShow: false,
        url: ''
      },
      prelang: 'operation',
      options: {
        height: 300, // 默认高度-为了表头固定
        stripe: true, // 是否为斑马纹 table
        highlightCurrentRow: false, // 是否要高亮当前行
        border: true, // 是否有纵向边框
        lazy: false, // 是否需要懒加载
        fit: true, // 列的宽度是否自撑开
        multiSelect: true, //
        seqNo: true,
        isRefresh: true, // 是否显示刷新按钮
        isShowHide: true, // 是否显示显影按钮
        isSearch: false, // 高级查询按钮
        defaultOrderBy: { column: 'id', direction: 'desc' }
      },
      // 默认选中字段的值数组,使其禁选
      paramTemplateSelArr: [],
      // 默认选中字段
      paramTemplateSelCol: 'id',
      table: {
        total: 0,
        currentPage: 1,
        pageSize: 20,
        data: [],
        // 标题
        column: [
          {
            width: '100',
            minWidth: '100',
            prop: 'factoryName',
            label: '工厂',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            width: '100',
            minWidth: '100',
            prop: 'partNo',
            label: '零件号',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text',
            propVal: this.$route.query.partNo
          },
          {
            width: '100',
            minWidth: '100',
            prop: 'partName',
            label: '零件名称',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            width: '100',
            minWidth: '100',
            prop: 'warehouseName',
            label: '仓库',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            width: '100',
            minWidth: '100',
            prop: 'locationNo',
            label: '库位号',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            width: '100',
            minWidth: '100',
            prop: 'locationName',
            label: '库位名称',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            width: '100',
            minWidth: '100',
            prop: 'systemNo',
            label: '系统编号',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            width: '100',
            minWidth: '100',
            prop: 'partBatchNo',
            label: 'SN号',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            width: '100',
            minWidth: '100',
            prop: 'reelNumber',
            label: '载具编号',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // {
          //   width: '100',
          //   minWidth: '100',
          //   prop: 'startMetre',
          //   label: '起始米标',
          //   sort: true,
          //   isTrue: true,
          //   isSearch: true,
          //   searchInfoType: 'text'
          // },
          // {
          //   width: '100',
          //   minWidth: '100',
          //   prop: 'endMetre',
          //   label: '截止米标',
          //   sort: true,
          //   isTrue: true,
          //   isSearch: true,
          //   searchInfoType: 'text'
          // },
          // {
          //   width: '100',
          //   minWidth: '100',
          //   prop: 'outerColor',
          //   label: '外护颜色',
          //   sort: true,
          //   isTrue: true,
          //   isSearch: true,
          //   searchInfoType: 'text'
          // },
          // {
          //   width: '100',
          //   minWidth: '100',
          //   prop: 'insulationColor',
          //   label: '绝缘颜色',
          //   sort: true,
          //   isTrue: true,
          //   isSearch: true,
          //   searchInfoType: 'text'
          // },
          {
            width: '100',
            minWidth: '100',
            prop: 'customerOrderNo',
            label: '销售订单号',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            width: '100',
            minWidth: '100',
            prop: 'mpsNo',
            label: '主生产计划号',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            width: '100',
            minWidth: '100',
            prop: 'stockQuantity',
            label: '库存数量',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            width: '100',
            minWidth: '100',
            prop: 'reserveQuantity',
            label: '预留数量',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            width: '100',
            minWidth: '120',
            prop: 'availableStockQuantity',
            label: '可用库存数量',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            width: '100',
            minWidth: '100',
            prop: 'unit',
            label: '单位',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            width: '100',
            minWidth: '120',
            prop: 'sstockQuantity',
            label: '库存数量2',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            width: '100',
            minWidth: '120',
            prop: 'savailableStockQuantity',
            label: '可用库存数量2',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            width: '100',
            minWidth: '100',
            prop: 'sunit',
            label: '单位2',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '100',
            prop: 'status',
            label: '状态',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '100',
            prop: 'ifsBatchNo',
            label: 'IFS批次号',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '100',
            prop: 'sourceName',
            label: '来源',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          }
        ],
        materialTypeList: []
      },
      addOrUpdateVisible: false
    }
  },
  components: {
    ttable
  },
  methods: {
    saveSelectRow() {
      this.$emit(
        'listenToPartEvent',
        this.multipleSelection,
        this.parentSelectedObj,
        this.parentSelectedIndex
      )
      this.innerVisible = false
    },
    handleCurrentChange(row) {
      this.currentRow = row
    },
    handleSelectionChange(val) {
      // 多行选中
      this.multipleSelection = val
    },
    getData() {
      // 获取不可选中的数据
      queryUsingApplyDetail().then((response) => {
        const resData = response.data
        console.log(resData)
        this.paramTemplateSelArr = resData.data
        if (this.$refs.commonPartTable !== undefined) {
          // 默认的过滤条件
          const queryParam = []
          queryParam.push(
            Object.assign({
              prop: 'locationNo',
              searchInfoType: 'text',
              propVal: '001'
            })
          )
          this.$refs.commonPartTable.setQueryParam(queryParam)
          this.$refs.commonPartTable.getDataList()
        }
      })
    }
    // getMaterialType(type) {
    //   remote(type).then((response) => {
    //     const code = response.data.code
    //     if (code === 0) {
    //       const _data = response.data.data
    //       this.materialTypeList = _data
    //     }
    //   })
    // },
    // getMaterialTypeType(row, column, cellValue) {
    //   this.materialTypeList.forEach((obj) => {
    //     if (obj.value == cellValue) {
    //       cellValue = obj.label
    //     }
    //   })
    //   return cellValue
    // }
  },
  watch: {
    currshowlist() {
      this.innerVisible = this.currshowlist
      if (this.currshowlist) {
        this.$nextTick(() => {
          this.getData()
        })
      }
    }
  },
  mounted() {
    // this.getMaterialType('material_type')
  }
}
</script>
<style>
.part-dialog .el-dialog__header {
  padding: 10px 20px 10px;
}
.part-dialog .el-dialog__header .el-dialog__headerbtn {
  top: 10px;
}
.part-dialog .el-dialog__body {
  padding: 5px 20px;
}

.part-dialog .el-dialog__footer {
  padding: 5px 20px 10px;
}

.part-dialog .el-dialog__body .avue-crud__pagination {
  margin-top: 0px;
  margin-bottom: 5px;
}
</style>
